@@ -6,10 +6,16 @@ import configparser
 import pathlib
 import time
 import logging
-import appdaemon.plugins.hass.hassapi as hass
 from omnik.ha_logger import hybridlogger
 from omnik import RepeatedJob
 from omnik.datalogger import DataLogger
+try:
+    # AppDeamon is only needed when run used with AppDaemon
+    import appdaemon.plugins.hass.hassapi as hass
+except ImportError:
+    # AppDeamon is not needed when run in command mode uses dummy class
+    class hass(object):
+        Hass = object
 
 logger = logging.getLogger(__name__)
 
